<?php

namespace Drupal\bigvideo\Plugin\ContextReaction;

use Drupal\context\ContextReactionPluginBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a content reaction that will let you add a background video to page.
 *
 * @ContextReaction(
 *   id = "bigvideo",
 *   label = @Translation("BigVideo background")
 * )
 */
class AttachVideo extends ContextReactionPluginBase implements ContainerFactoryPluginInterface {

  /**
   * BigVideo Source entity storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $bigvideoSourceStorage;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->bigvideoSourceStorage = $entity_type_manager->getStorage('bigvideo_source');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->t('Lets you add a background video.');
  }

  /**
   * {@inheritdoc}
   */
  public function execute() {
    return $this->bigvideoSourceStorage->load($this->configuration['source']);
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $sources = $this->bigvideoSourceStorage->loadMultiple();
    $options = [];
    /** @var \Drupal\bigvideo\Entity\BigvideoSource $source */
    foreach ($sources as $source) {
      $options[$source->id()] = $source->label();
    }
    $form['source'] = [
      '#type' => 'select',
      '#title' => $this->t('Source'),
      '#options' => $options,
      '#required' => TRUE,
      '#default_value' => $this->configuration['source'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['source'] = $form_state->getValue('source');
  }

}
